@@ -1,21 +1,14 @@
 import re
 from datetime import datetime
 from pathlib import Path
-from typing import (
-    Optional,
-    Sequence,
-    Dict,
-    Mapping,
-    Set,
-    Union,
-)
+from typing import Dict, Mapping, Optional, Sequence, Set, Union
 from urllib.parse import quote, urlparse
 
 import datacube.utils.uris as dc_uris
 
 from eodatasets3 import utils
 from eodatasets3.model import DEA_URI_PREFIX, Location
-from eodatasets3.properties import Eo3Interface, Eo3Dict
+from eodatasets3.properties import Eo3Dict, Eo3Interface
 
 # Needed when packaging zip or tar files.
 dc_uris.register_scheme("zip", "tar")
